@@ -9,7 +9,13 @@ from nose.tools import assert_raises
 from tests import utils
 
 from freezegun import freeze_time
-from freezegun.api import FakeDatetime, FakeDate
+from freezegun.api import FakeDatetime, FakeDate, BaseFakeTime
+
+try:
+    import maya
+
+except ImportError:
+    maya = None
 
 
 class temp_locale(object):
@@ -201,6 +207,17 @@ def test_time_gmtime():
         assert time_struct.tm_isdst == -1
 
 
+def test_time_clock():
+    with freeze_time('2012-01-14 03:21:34'):
+        assert time.clock() == 0
+
+        with freeze_time('2012-01-14 03:21:35'):
+            assert time.clock() == 1
+
+        with freeze_time('2012-01-14 03:21:36'):
+            assert time.clock() == 2
+
+
 class modify_timezone(object):
 
     def __init__(self, new_timezone):
@@ -302,6 +319,19 @@ def test_generator_object():
     assert_raises(StopIteration, freeze_time, frozen_datetimes)
 
 
+def test_maya_datetimes():
+    if not maya:
+        raise skip.SkipTest("maya is optional since it's not supported for "
+                            "enough python versions")
+
+    with freeze_time(maya.when("October 2nd, 1997")):
+        assert datetime.datetime.now() == datetime.datetime(
+            year=1997,
+            month=10,
+            day=2
+        )
+
+
 def test_old_datetime_object():
     frozen_datetime = datetime.datetime(year=1, month=7, day=12,
                                         hour=15, minute=6, second=3)
@@ -578,3 +608,37 @@ def test_freeze_with_timezone_aware_datetime_in_non_utc():
     utc_now = datetime.datetime.utcnow()
     assert utc_now.tzinfo is None
     assert utc_now == datetime.datetime(1970, 1, 1, 4)
+
+
+@freeze_time('2015-01-01')
+def test_time_with_nested():
+    from time import time
+    first = 1420070400.0
+    second = 1420070760.0
+
+    assert time() == first
+    with freeze_time('2015-01-01T00:06:00'):
+        assert time() == second
+
+
+def test_should_use_real_time():
+    frozen = datetime.datetime(2015, 3, 5)
+    expected_frozen = 1425513600.0
+    # TODO: local time seems to leak the local timezone, so this test fails in CI
+    # expected_frozen_local = (2015, 3, 5, 1, 0, 0, 3, 64, -1)
+    expected_frozen_gmt = (2015, 3, 5, 0, 0, 0, 3, 64, -1)
+    expected_clock = 0
+
+    BaseFakeTime.call_stack_inspection_limit = 100  # just to increase coverage
+
+    with freeze_time(frozen):
+        assert time.time() == expected_frozen
+        # assert time.localtime() == expected_frozen_local
+        assert time.gmtime() == expected_frozen_gmt
+        assert time.clock() == expected_clock
+
+    with freeze_time(frozen, ignore=['_pytest', 'nose']):
+        assert time.time() != expected_frozen
+        # assert time.localtime() != expected_frozen_local
+        assert time.gmtime() != expected_frozen_gmt
+        assert time.clock() != expected_clock
